==> haskell-xml-types-0.3.6-11-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-xml-types.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xml-types
version: 0.3.6
id: xml-types-0.3.6-8U94ZZax169GYLVDpT1mig
key: xml-types-0.3.6-8U94ZZax169GYLVDpT1mig
license: MIT
maintainer: jmillikin@gmail.com
stability: experimental
homepage: https://john-millikin.com/software/haskell-xml/
synopsis: Basic types for representing XML
category: Text, XML
author: John Millikin <jmillikin@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Data.XML.Types
abi: d5c752ba65b163e7bdddd7a60950098d
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/xml-types-0.3.6
library-dirs: /usr/lib/ghc-8.2.2/site-local/xml-types-0.3.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/xml-types-0.3.6
hs-libraries: HSxml-types-0.3.6-8U94ZZax169GYLVDpT1mig
depends:
    base-4.10.1.0 deepseq-1.4.3.0 text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=b7726d921cac66adc5c8f9f66f5b25f0
haddock-interfaces: /usr/share/doc/haskell-xml-types/html/xml-types.haddock
haddock-html: /usr/share/doc/haskell-xml-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xml-types-0.3.6-12-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-xml-types.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xml-types
version: 0.3.6
id: xml-types-0.3.6-GzQgX9Brh0VH8ue9BSAlZr
key: xml-types-0.3.6-GzQgX9Brh0VH8ue9BSAlZr
license: MIT
maintainer: jmillikin@gmail.com
stability: experimental
homepage: https://john-millikin.com/software/haskell-xml/
synopsis: Basic types for representing XML
category: Text, XML
author: John Millikin <jmillikin@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Data.XML.Types
abi: edf071c0face4ef12f6ee1822aae3316
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/xml-types-0.3.6
library-dirs: /usr/lib/ghc-8.2.2/site-local/xml-types-0.3.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/xml-types-0.3.6
hs-libraries: HSxml-types-0.3.6-GzQgX9Brh0VH8ue9BSAlZr
depends:
    base-4.10.1.0 deepseq-1.4.3.0 text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
haddock-interfaces: /usr/share/doc/haskell-xml-types/html/xml-types.haddock
haddock-html: /usr/share/doc/haskell-xml-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
